==> gjacktransport-0.2.1.tar.gz: gjacktransport-0.2.1/src/main.c <==
/* gjacktransport - jack transport slider
 *  Copyright (C) 2006 Robin Gareus  <robin AT gareus.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "interface.h"
#include "support.h"

#include "gjack.h"

GtkWidget *window1;

// defined in callbacks.c
gboolean  gpolljack (gpointer data);
void initialize_gjt (void);

void usage (char *program_name) {
	printf(" usage: %s [end-marker]\n",program_name);
	printf("        %s [start-marker] [end-marker]\n",program_name);
	printf("     unit: seconds.\n");
	exit(1);
}

static GdkPixmap *gjt_icon_pixmap;
static GdkBitmap *gjt_icon_mask;

#include "gjt_icon.xpm"

int
main (int argc, char *argv[])
{

 // pthread_t pjackpollthread;
#ifdef ENABLE_NLS
  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);
#endif

  gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
                      argc, argv,
                      GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
                      NULL);

  if (argc > 3 ) usage(argv[0]);
  if (argc > 1 && !strcmp(argv[1],"-h")) usage(argv[0]);
  if (argc > 1 && !strcmp(argv[1],"-V")) { printf ("gjacktransport %s\n", VERSION); exit(0); }

  initialize_gjt();

  window1 = create_window1 ();
  gtk_widget_show (window1);

  gjt_icon_pixmap = gdk_pixmap_create_from_xpm_d (window1->window, &gjt_icon_mask, NULL, gjt_icon_xpm);

  gdk_window_set_icon(window1->window, NULL, gjt_icon_pixmap, gjt_icon_mask);
  //gdk_pixbuf_unref (window1_icon_pixbuf);
  GtkWidget *w = lookup_widget(window1,"combobox1");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),6);

  w = lookup_widget(window1,"combobox2");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),2);

  w = lookup_widget(window1,"combobox3");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);
  w = lookup_widget(window1,"combobox4");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);
  w = lookup_widget(window1,"combobox5");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);
// update_startend(UNIT_SEC);
//w = lookup_widget(window1,"radiobutton4");
//gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w),TRUE);

  if (argc == 3) {
    /* set start end end marker */
    gdouble val = strtod(argv[1],NULL);
    w = lookup_widget(window1,"spinbutton1");
    gtk_spin_button_set_value(GTK_SPIN_BUTTON(w),val);
    val = strtod(argv[2],NULL);
    w = lookup_widget(window1,"spinbutton2");
    gtk_spin_button_set_value(GTK_SPIN_BUTTON(w),val);
  } else if (argc == 2) {
    /* set end marker */
    gdouble val = strtod(argv[1],NULL);
    w = lookup_widget(window1,"spinbutton2");
    gtk_spin_button_set_value(GTK_SPIN_BUTTON(w),val);
  }
  g_timeout_add(40,gpolljack,NULL);
  gtk_main ();
  return 0;
}

==> gjacktransport-0.2.2.tar.gz: gjacktransport-0.2.2/src/main.c <==
/* gjacktransport - jack transport slider
 *  Copyright (C) 2006 Robin Gareus  <robin AT gareus.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <gnome.h>

#include "interface.h"
#include "support.h"

#include "gjack.h"
#include "gjacktransport.h"

GtkWidget *window1;

gjtdata stg[MAX_MEM]; // settings
int mem = 0; // current mem
const int want_quiet = 0;

#ifdef HAVE_LASH
# include <lash/lash.h>
void lash_setup(void); //< prototype - fn defined in lash.c
void lash_process(void);
lash_client_t *lash_client;
#endif

// prototypes - defined in callbacks.c
gboolean  gpolljack (gpointer data);
void initialize_gjt (void);
void update_spinbtns(void);

static GdkPixmap *gjt_icon_pixmap;
static GdkBitmap *gjt_icon_mask;
#include "gjt_icon.xpm"


void usage (char *program_name) {
	printf(" usage: %s [end-marker]\n",program_name);
	printf("        %s [start-marker] [end-marker]\n",program_name);
	printf("        %s {-h | --help | -V} - prints help/version info.\n",program_name);
	printf("     unit for slider marks: seconds.\n");
	exit(1);
}

void load_rc (void) {
// TODO read ~/.gjacktransportrc or use gconf ? eg.
//stg[1].unit=UNIT_MIN;
  ;
}

gboolean glashproc (gpointer data) {
  lash_process();
  return(TRUE);
}

int main (int argc, char *argv[]) {

 GtkWidget *w;

 // pthread_t pjackpollthread;
#ifdef ENABLE_NLS
  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);
#endif

  gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
                      argc, argv,
                      GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
                      NULL);

#ifdef HAVE_LASH
  lash_args_t *lash_args = lash_extract_args(&argc, &argv);
#endif

  initialize_gjt();
  load_rc();

  if (argc > 3 ) usage(argv[0]);
  if (argc > 1 && !strcmp(argv[1],"-h")) usage(argv[0]);
  if (argc > 1 && !strcmp(argv[1],"--help")) usage(argv[0]);
  if (argc > 1 && !strcmp(argv[1],"-V")) { printf ("gjacktransport %s\n (C) GPL 2007 Robin Gareus <robin@gareus.org>\n", VERSION); exit(0); }

  if (argc == 3) {
    /* set start end end marker */
    stg[0].unit=UNIT_SEC;
    stg[0].start=strtod(argv[1],NULL); //* unit_table[stg[0].unit];
    stg[0].end=strtod(argv[2],NULL); //* unit_table[stg[0].unit];
  } else if (argc == 2) {
    /* set end marker only */
    stg[0].unit=UNIT_SEC;
    stg[0].end=strtod(argv[1],NULL);; //* unit_table[stg[0].unit];
  }
#ifdef HAVE_LASH
  lash_client = lash_init (lash_args, PACKAGE_NAME, 0  | LASH_Config_Data_Set ,LASH_PROTOCOL (2,0));
  if (!lash_client) {
    fprintf(stderr, "could not initialise LASH!\n");
  } else { 
    lash_setup();
    if (!want_quiet) printf("Connected to LASH.\n");
  }
  //lash_args_destroy(lash_args);
#endif

  window1 = create_window1 ();
  gtk_widget_show (window1);

  gjt_icon_pixmap = gdk_pixmap_create_from_xpm_d (window1->window, &gjt_icon_mask, NULL, gjt_icon_xpm);

  gdk_window_set_icon(window1->window, NULL, gjt_icon_pixmap, gjt_icon_mask);
  //gdk_pixbuf_unref (window1_icon_pixbuf);
 
  update_spinbtns();

  w = lookup_widget(window1,"combobox1");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),6);

  w = lookup_widget(window1,"combobox2");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),2);

  w = lookup_widget(window1,"combobox3");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);
  w = lookup_widget(window1,"combobox4");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);
  w = lookup_widget(window1,"combobox5");
  gtk_combo_box_set_active (GTK_COMBO_BOX(w),0);

// update_startend(UNIT_SEC);

  g_timeout_add(40,gpolljack,NULL);
#ifdef HAVE_LASH
  g_timeout_add(250,glashproc,NULL);
#endif
  gtk_main ();
  return 0;
}
/* vi:set ts=8 sts=2 sw=2: */
